@@ -19,7 +19,7 @@ class BaseAuthEntityServerConnector(EntityServerConnector):
     Config = EntityServerConnector.Config
 
     def __init__(self, config: Config, context: Context) -> None:
-        self._server_name = context.server_name
+        self._server_name = context.project_name
         super(BaseAuthEntityServerConnector, self).__init__(config, context)
 
     def _construct_headers(self) -> dict[str, str]:
